@@ -1,6 +1,7 @@
 /* Grid class implementation
    (non-inline private or protected functions).
-   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -26,7 +27,7 @@ site: http://www.cs.unipr.it/ppl/ . */
 #include "Grid.defs.hh"
 #include "Grid_Generator.defs.hh"
 #include "Scalar_Products.defs.hh"
-#include <cassert>
+#include "assert.hh"
 #include <string>
 #include <iostream>
 #include <sstream>
@@ -64,7 +65,7 @@ PPL::Grid::construct(dimension_type num_dimensions,
     cgs.increase_space_dimension(space_dim);
     const_cast<Congruence_System&>(con_sys).swap(cgs);
 
-    assert(OK());
+    PPL_ASSERT(OK());
     return;
   }
 
@@ -103,12 +104,12 @@ PPL::Grid::construct(dimension_type num_dimensions,
 void
 PPL::Grid::construct(Congruence_System& cgs) {
   // Protecting against space dimension overflow is up to the caller.
-  assert(cgs.space_dimension() <= max_space_dimension());
+  PPL_ASSERT(cgs.space_dimension() <= max_space_dimension());
   // Preparing con_sys and gen_sys is up to the caller.
-  assert(cgs.space_dimension() == con_sys.space_dimension());
-  assert(cgs.space_dimension() == gen_sys.space_dimension());
-  assert(con_sys.has_no_rows());
-  assert(gen_sys.has_no_rows());
+  PPL_ASSERT(cgs.space_dimension() == con_sys.space_dimension());
+  PPL_ASSERT(cgs.space_dimension() == gen_sys.space_dimension());
+  PPL_ASSERT(con_sys.has_no_rows());
+  PPL_ASSERT(gen_sys.has_no_rows());
 
   // Set the space dimension.
   space_dim = cgs.space_dimension();
@@ -130,23 +131,23 @@ PPL::Grid::construct(Congruence_System& cgs) {
 	  // Insert the zero dim false congruence system into `con_sys'.
 	  // `gen_sys' is already in empty form.
 	  con_sys.insert(Congruence::zero_dim_false());
-	  assert(OK());
+	  PPL_ASSERT(OK());
 	  return;
 	}
     set_zero_dim_univ();
   }
-  assert(OK());
+  PPL_ASSERT(OK());
 }
 
 void
 PPL::Grid::construct(Grid_Generator_System& ggs) {
   // Protecting against space dimension overflow is up to the caller.
-  assert(ggs.space_dimension() <= max_space_dimension());
+  PPL_ASSERT(ggs.space_dimension() <= max_space_dimension());
   // Preparing con_sys and gen_sys is up to the caller.
-  assert(ggs.space_dimension() == con_sys.space_dimension());
-  assert(ggs.space_dimension() == gen_sys.space_dimension());
-  assert(con_sys.has_no_rows());
-  assert(gen_sys.has_no_rows());
+  PPL_ASSERT(ggs.space_dimension() == con_sys.space_dimension());
+  PPL_ASSERT(ggs.space_dimension() == gen_sys.space_dimension());
+  PPL_ASSERT(con_sys.has_no_rows());
+  PPL_ASSERT(gen_sys.has_no_rows());
 
   // Set the space dimension.
   space_dim = ggs.space_dimension();
@@ -174,14 +175,14 @@ PPL::Grid::construct(Grid_Generator_System& ggs) {
     set_generators_up_to_date();
   }
 
-  assert(OK());
+  PPL_ASSERT(OK());
 }
 
 PPL::Grid::Three_Valued_Boolean
 PPL::Grid::quick_equivalence_test(const Grid& y) const {
   // Private method: the caller must ensure the following.
-  assert(space_dim == y.space_dim);
-  assert(!marked_empty() && !y.marked_empty() && space_dim > 0);
+  PPL_ASSERT(space_dim == y.space_dim);
+  PPL_ASSERT(!marked_empty() && !y.marked_empty() && space_dim > 0);
 
   const Grid& x = *this;
 
@@ -236,8 +237,8 @@ PPL::Grid::quick_equivalence_test(const Grid& y) const {
 bool
 PPL::Grid::is_included_in(const Grid& y) const {
   // Private method: the caller must ensure the following.
-  assert(space_dim == y.space_dim);
-  assert(!marked_empty() && !y.marked_empty() && space_dim > 0);
+  PPL_ASSERT(space_dim == y.space_dim);
+  PPL_ASSERT(!marked_empty() && !y.marked_empty() && space_dim > 0);
 
   const Grid& x = *this;
 
@@ -255,8 +256,8 @@ PPL::Grid::is_included_in(const Grid& y) const {
     y.minimize();
 #endif
 
-  assert(x.OK());
-  assert(y.OK());
+  PPL_ASSERT(x.OK());
+  PPL_ASSERT(y.OK());
 
   const Grid_Generator_System& gs = x.gen_sys;
   const Congruence_System& cgs = y.con_sys;
@@ -286,7 +287,16 @@ PPL::Grid::bounds(const Linear_Expression& expr,
     // Minimizing found `this' empty.
     return true;
 
-  // The generators are up to date.
+  return bounds_no_check(expr);
+}
+
+bool
+PPL::Grid::bounds_no_check(const Linear_Expression& expr) const {
+  // The dimension of `expr' must be at most the dimension of *this.
+  PPL_ASSERT(space_dim > 0 && space_dim >= expr.space_dimension());
+  PPL_ASSERT(generators_are_minimized() && !marked_empty());
+
+  // The generators are up to date and minimized.
   for (dimension_type i = gen_sys.num_rows(); i-- > 0; ) {
     const Grid_Generator& g = gen_sys[i];
     // Only lines and parameters in `*this' can cause `expr' to be
@@ -301,6 +311,85 @@ PPL::Grid::bounds(const Linear_Expression& expr,
   return true;
 }
 
+bool
+PPL::Grid::frequency_no_check(const Linear_Expression& expr,
+                     Coefficient& freq_n, Coefficient& freq_d,
+                     Coefficient& val_n, Coefficient& val_d) const {
+
+  // The dimension of `expr' must be at most the dimension of *this.
+  PPL_ASSERT(space_dim >= expr.space_dimension());
+  PPL_ASSERT(generators_are_minimized() && !marked_empty());
+
+  // The generators are up to date and minimized and the grid is non-empty.
+
+  // If the grid is bounded for the expression `expr',
+  // then `expr' has a constant value and the frequency is 0.
+  if (bounds_no_check(expr)) {
+    freq_n = 0;
+    freq_d = 1;
+    // Find the value of the constant expression.
+    const Grid_Generator& point = gen_sys[0];
+    val_d = point.divisor();
+    Scalar_Products::homogeneous_assign(val_n, expr, point);
+    val_n += expr.inhomogeneous_term() * val_d;
+    // Reduce `val_n' and `val_d'.
+    PPL_DIRTY_TEMP_COEFFICIENT(gcd);
+    gcd_assign(gcd, val_n, val_d);
+    exact_div_assign(val_n, val_n, gcd);
+    exact_div_assign(val_d, val_d, gcd);
+    return true;
+  }
+
+  // The frequency is the gcd of the scalar products of the parameters
+  // in `gen_sys'.
+  dimension_type num_rows = gen_sys.num_rows();
+  PPL_DIRTY_TEMP_COEFFICIENT(sp);
+  freq_n = 0;
+
+  // As the generators are minimized, `gen_sys[0]' is a point
+  // and considered later.
+  for (dimension_type row = 1; row < num_rows; ++row) {
+    const Grid_Generator& gen = gen_sys[row];
+    Scalar_Products::homogeneous_assign(sp, expr, gen);
+    if (gen.is_line()) {
+      if (sgn(sp) != 0)
+          return false;
+      continue;
+    }
+    // `gen' must be a parameter.
+    PPL_ASSERT(gen.is_parameter());
+    if (sgn(sp) != 0)
+    gcd_assign(freq_n, freq_n, sp);
+  }
+  const Grid_Generator& point = gen_sys[0];
+  PPL_ASSERT(point.is_point());
+
+  // The denominator of the frequency and of the value is
+  // the divisor for the generators.
+  freq_d = point.divisor();
+  val_d = freq_d;
+
+  // As point is a grid generator, homogeneous_assign() must be used.
+  Scalar_Products::homogeneous_assign(val_n, expr, point);
+  val_n += expr.inhomogeneous_term() * val_d;
+
+  // Reduce `val_n' by the frequency `freq_n'.
+  val_n %= freq_n;
+
+  PPL_DIRTY_TEMP_COEFFICIENT(gcd);
+  // Reduce `freq_n' and `freq_d'.
+  gcd_assign(gcd, freq_n, freq_d);
+  exact_div_assign(freq_n, freq_n, gcd);
+  exact_div_assign(freq_d, freq_d, gcd);
+
+  // Reduce `val_n' and `val_d'.
+  gcd_assign(gcd, val_n, val_d);
+  exact_div_assign(val_n, val_n, gcd);
+  exact_div_assign(val_d, val_d, gcd);
+
+  return true;
+}
+
 bool
 PPL::Grid::max_min(const Linear_Expression& expr,
 		   const char* method_call,
@@ -374,10 +463,10 @@ PPL::Grid::set_empty() {
 void
 PPL::Grid::update_congruences() const {
   // The caller must ensure that the generators are up to date.
-  assert(space_dim > 0);
-  assert(!marked_empty());
-  assert(!gen_sys.has_no_rows());
-  assert(gen_sys.space_dimension() > 0);
+  PPL_ASSERT(space_dim > 0);
+  PPL_ASSERT(!marked_empty());
+  PPL_ASSERT(!gen_sys.has_no_rows());
+  PPL_ASSERT(gen_sys.space_dimension() > 0);
 
   Grid& gr = const_cast<Grid&>(*this);
 
@@ -386,7 +475,7 @@ PPL::Grid::update_congruences() const {
 
   // `gen_sys' contained rows before being reduced, so it should
   // contain at least a single point afterward.
-  assert(!gen_sys.has_no_rows());
+  PPL_ASSERT(!gen_sys.has_no_rows());
 
   // Populate `con_sys' with congruences characterizing the grid
   // described by `gen_sys'.
@@ -399,9 +488,9 @@ PPL::Grid::update_congruences() const {
 
 bool
 PPL::Grid::update_generators() const {
-  assert(space_dim > 0);
-  assert(!marked_empty());
-  assert(congruences_are_up_to_date());
+  PPL_ASSERT(space_dim > 0);
+  PPL_ASSERT(!marked_empty());
+  PPL_ASSERT(congruences_are_up_to_date());
 
   Grid& x = const_cast<Grid&>(*this);
 
@@ -451,7 +540,7 @@ PPL::Grid::minimize() const {
 	// Both systems are up to date, and the empty case is handled
 	// above, so the grid should contain points.
 	bool empty = simplify(gr.con_sys, gr.dim_kinds);
-	assert(!empty);
+	PPL_ASSERT(!empty);
 #else
 	simplify(gr.con_sys, gr.dim_kinds);
 #endif
@@ -466,15 +555,15 @@ PPL::Grid::minimize() const {
     else {
       // Updating the generators may reveal that `*this' is empty.
       const bool ret = update_generators();
-      assert(OK());
+      PPL_ASSERT(OK());
       return ret;
     }
   }
   else {
-    assert(generators_are_up_to_date());
+    PPL_ASSERT(generators_are_up_to_date());
     update_congruences();
   }
-  assert(OK());
+  PPL_ASSERT(OK());
   return true;
 }
 
@@ -484,14 +573,14 @@ PPL::Grid::normalize_divisors(Grid_Generator_System& sys,
 #ifndef NDEBUG
   const dimension_type num_rows = gen_sys.num_rows();
 #endif
-  assert(num_rows > 0);
+  PPL_ASSERT(num_rows > 0);
 
   // Find the first point in gen_sys.
   dimension_type row = 0;
   while (gen_sys[row].is_line_or_parameter()) {
     ++row;
     // gen_sys should have at least one point.
-    assert(row < num_rows);
+    PPL_ASSERT(row < num_rows);
   }
   Grid_Generator& first_point = gen_sys[row];
   const Coefficient& gen_sys_divisor = first_point.divisor();
@@ -501,7 +590,7 @@ PPL::Grid::normalize_divisors(Grid_Generator_System& sys,
   for (dimension_type i = row + 1; i < num_rows; ++i) {
     Grid_Generator& g = gen_sys[i];
     if (g.is_parameter_or_point())
-      assert(gen_sys_divisor == g.divisor());
+      PPL_ASSERT(gen_sys_divisor == g.divisor());
   }
 #endif // !defined(NDEBUG)
 
@@ -522,7 +611,7 @@ void
 PPL::Grid::normalize_divisors(Grid_Generator_System& sys,
 			      Coefficient& divisor,
 			      const Grid_Generator* first_point) {
-  assert(divisor >= 0);
+  PPL_ASSERT(divisor >= 0);
   if (sys.space_dimension() > 0 && divisor > 0) {
     dimension_type row = 0;
     dimension_type num_rows = sys.num_rows();
@@ -530,7 +619,7 @@ PPL::Grid::normalize_divisors(Grid_Generator_System& sys,
     if (first_point)
       lcm_assign(divisor, divisor, (*first_point).divisor());
     else {
-      assert(num_rows > 0);
+      PPL_ASSERT(num_rows > 0);
       // Move to the first point or parameter.
       while (sys[row].is_line())
 	if (++row == num_rows)
@@ -556,8 +645,8 @@ PPL::Grid::normalize_divisors(Grid_Generator_System& sys,
 
 void
 PPL::Grid::add_congruence_no_check(const Congruence& cg) {
-  assert(!marked_empty());
-  assert(space_dim >= cg.space_dimension());
+  PPL_ASSERT(!marked_empty());
+  PPL_ASSERT(space_dim >= cg.space_dimension());
 
   // Dealing with a zero-dimensional space grid first.
   if (space_dim == 0) {
@@ -577,13 +666,13 @@ PPL::Grid::add_congruence_no_check(const Congruence& cg) {
 
   // Note: the congruence system may have become unsatisfiable, thus
   // we do not check for satisfiability.
-  assert(OK());
+  PPL_ASSERT(OK());
 }
 
 void
 PPL::Grid::add_constraint_no_check(const Constraint& c) {
-  assert(!marked_empty());
-  assert(space_dim >= c.space_dimension());
+  PPL_ASSERT(!marked_empty());
+  PPL_ASSERT(space_dim >= c.space_dimension());
 
   if (c.is_inequality()) {
     // Only trivial inequalities can be handled.
@@ -597,15 +686,15 @@ PPL::Grid::add_constraint_no_check(const Constraint& c) {
     throw_invalid_constraint("add_constraint(c)", "c");
   }
 
-  assert(c.is_equality());
+  PPL_ASSERT(c.is_equality());
   Congruence cg(c);
   add_congruence_no_check(cg);
 }
 
 void
 PPL::Grid::refine_no_check(const Constraint& c) {
-  assert(!marked_empty());
-  assert(space_dim >= c.space_dimension());
+  PPL_ASSERT(!marked_empty());
+  PPL_ASSERT(space_dim >= c.space_dimension());
 
   if (c.is_equality()) {
     Congruence cg(c);
