@@ -1,5 +1,6 @@
 /* Test BD_Shape::is_disjoint_from(const BD_Shape& y).
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -185,10 +186,7 @@ BEGIN_MAIN
   DO_TEST(test01);
   DO_TEST(test02);
   DO_TEST(test03);
-#ifndef __alpha__
-  // Exception handling is broken in GCC on the Alpha.
   DO_TEST(test04);
-#endif
   DO_TEST(test05);
   DO_TEST(test06);
   DO_TEST(test07);
