@@ -1,5 +1,6 @@
 /* Test that the right exceptions are thrown in case of incorrect uses.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -893,10 +894,7 @@ BEGIN_MAIN
   DO_TEST(test16);
   DO_TEST(test17);
   DO_TEST(test18);
-#ifndef __alpha__
-  // Exception handling is broken in GCC on the Alpha.
   DO_TEST(test19);
-#endif
   DO_TEST(test20);
   DO_TEST(test21);
   DO_TEST(test22);
