@@ -1,7 +1,8 @@
 #!/bin/sh
 
 # Erases all files listed in the cutting markers found on stdin.
-# Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
+# Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
+# Copyright (C) 2010-2011 BUGSENG srl (http://bugseng.com)
 #
 # This file is part of the Parma Polyhedra Library (PPL).
 #
@@ -22,16 +23,13 @@
 # For the most up-to-date information see the Parma Polyhedra Library
 # site: http://www.cs.unipr.it/ppl/ .
 
-CUTTING_MARKER_PREFIX="%<--%<--%<-- "
+___BEGIN_OF_FILE___() {
+  rm -f $1
+  cat > /dev/null
+}
 
-while IFS= read -r line
-do
-  case "$line" in
-      $CUTTING_MARKER_PREFIX*)
-	  read dummy file <<EOF
-$line
-EOF
-	  rm -f "$file"
-	  ;;
-  esac
-done
+___END_OF_FILE___() {
+    :
+}
+
+. $1
